Complex-Valued Neural Networks (CVNN)
=====================================

Done by @NEGU93 - J. Agustin Barrachina

|Documentation Status|

This is a library that uses `Tensorflow <https://www.tensorflow.org>`__
as a back-end to do complex-valued neural networks as, as far as I know,
CVNNs are barely supported by Tensorflow and not even supported yet for
`pytorch <https://github.com/pytorch/pytorch/issues/755>`__ (reason why
I decided to use Tensorflow for this library).

Please `Read the
Docs <https://complex-valued-neural-networks.readthedocs.io/en/latest/index.html>`__

About me & Motivation
---------------------

`My personal website <https://negu93.github.io/agustinbarrachina/>`__

I am a PhD student from `Ecole
CentraleSupelec <https://www.centralesupelec.fr/>`__ with a scholarship
from `ONERA <https://www.onera.fr/en>`__ and the
`DGA <https://www.defense.gouv.fr/dga>`__

I am basically working with Complex-Valued Neural Networks for my PhD
topic. In the need of making my coding more dynamic I build a library
not to have to repeat the same code over and over for little changes and
accelerate therefore my coding.

Cite Me
-------

::

   @MISC {NEGU93-CVNN,
       author       = {J. Agustin Barrachina},
       title        = {Complex-Valued Neural Networks (CVNN)},
       howpublished = {\url{https://github.com/NEGU93/cvnn}},
       journal      = {GitHub repository},
       year         = {2019}
   }

.. |Documentation Status| image:: https://readthedocs.org/projects/complex-valued-neural-networks/badge/?version=latest
   :target: https://complex-valued-neural-networks.readthedocs.io/en/latest/?badge=latest
